<template>
  <a-card :bordered="false">
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
          <a-col :md="6" :sm="8">
            <a-form-item label="项目名称">
              <j-input placeholder="请输入项目名称" v-model="queryParam.xmmc"></j-input>
            </a-form-item>
          </a-col>

          <template v-if="toggleSearchStatus"> </template>
          <a-col :md="6" :sm="8">
            <span style="float: left; overflow: hidden" class="table-page-search-submitButtons">
              <a-button type="primary" @click="searchQuery" icon="search">查询</a-button>
              <a-button type="primary" @click="searchReset" icon="reload" style="margin-left: 8px">重置</a-button>
              <a-button style="margin-left: 30px" type="primary" icon="download" @click="handleExportXls('项目一览表')"
                >导出</a-button
              >
              <!-- <a @click="handleToggleSearch" style="margin-left: 8px">
                {{ toggleSearchStatus ? '收起' : '展开' }}
                <a-icon :type="toggleSearchStatus ? 'up' : 'down'" />
              </a> -->
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>
    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <!-- <a-button type="primary" icon="download" @click="handleExportXls('项目一览表')">导出</a-button> -->
    </div>

    <!-- table区域-begin -->
    <div>
      <!-- <div class="ant-alert ant-alert-info" style="margin-bottom: 16px">
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择
        <a style="font-weight: 600">{{ selectedRowKeys.length }}</a
        >项
        <a style="margin-left: 24px" @click="onClearSelected">清空</a>
      </div> -->

      <a-table
        :scroll="{ x: 1500 }"
        bordered
        ref="table"
        size="middle"
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        :rowSelection="{ selectedRowKeys: selectedRowKeys, onChange: onSelectChange }"
        @change="handleTableChange"
      >
        <!-- 字符串超长截取省略号显示-->
        <span slot="esContent" slot-scope="text">
          <j-ellipsis :value="text" :length="12" />
        </span>
        <template slot="flowRate" slot-scope="text, record, index">
          <a-progress
            :strokeColor="getPercentColor(record.wcjd)"
            :format="getPercentFormat"
            :percent="record.wcjd"
            style="width: 120px"
          />
        </template>

        <span slot="action" slot-scope="text, record">
          <a @click="openBoard(record)">项目看板</a>

          <a-divider type="vertical" />
          <a-dropdown>
            <a class="ant-dropdown-link">更多 <a-icon type="down" /></a>
            <a-menu slot="overlay">
              <a-menu-item>
                <a @click="showTimeLine(record)">时间轴</a>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>
      </a-table>
    </div>
    <!-- table区域-end -->

    <!-- 表单区域 -->
    <time-line ref="timeLine"></time-line>
  </a-card>
</template>

<script>
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import JDictSelectTag from '@/components/dict/JDictSelectTag'
import { initDictOptions, filterMultiDictText } from '@/components/dict/JDictSelectUtil'
import TimeLine from './modules/TimeLine.vue'

export default {
  name: 'PMO',
  mixins: [JeecgListMixin],
  components: {
    JDictSelectTag,
    TimeLine,
  },
  data() {
    return {
      description: 'PMO',
      userDictOptions: [],
      // 表头
      columns: [
        {
          title: '序号',
          dataIndex: '',
          fixed: 'left',
          key: 'rowIndex',
          width: 50,
          align: 'center',
          customRender: function (t, r, index) {
            return parseInt(index) + 1
          },
        },
        {
          title: '项目名称',
          width: 200,
          fixed: 'left',
          dataIndex: 'xmmc',
          sorter: true,
          align: 'center',
          scopedSlots: { customRender: 'esContent' },
        },
        {
          title: '项目编号',
          dataIndex: 'xmbh',
          sorter: true,
          width: 100,
          align: 'center',
        },
        {
          title: '负责人',
          dataIndex: 'xmfzr_dictText',
          sorter: true,
          width: 90,
          align: 'center',
        },
        {
          title: '负责组别',
          dataIndex: 'xmfzz_dictText',
          sorter: true,
          width: 100,
          align: 'center',
        },
        {
          title: '项目类型',
          dataIndex: 'xmlx_dictText',
          sorter: true,
          width: 100,
          align: 'center',
        },
        {
          title: '当前阶段',
          dataIndex: 'dqjd',
          sorter: true,
          width: 100,
          align: 'center',
        },
        {
          title: '项目状态',
          dataIndex: 'xmzt_dictText',
          sorter: true,
          width: 100,
          align: 'center',
        },
        {
          title: '项目来源',
          dataIndex: 'xmly_dictText',
          sorter: true,
          width: 100,
          align: 'center',
        },
        {
          title: '等级',
          dataIndex: 'xmdj',
          align: 'center',
          width: 50,
        },
        {
          title: '重点课题',
          dataIndex: 'zdkt_dictText',
          sorter: true,
          width: 100,
        },
        {
          title: '重点项目',
          dataIndex: 'zdxm_dictText',
          sorter: true,
          width: 100,
          align: 'center',
        },
        {
          title: '结束标志',
          dataIndex: 'jsbz',
          sorter: true,
          width: 140,
          align: 'center',
        },
        {
          title: '周期计划',
          dataIndex: 'zqjh',
          sorter: true,
          width: 100,
          align: 'center',
        },
        {
          title: '工时计划',
          dataIndex: 'gsjh',
          sorter: true,
          width: 100,
          align: 'center',
        },
        {
          title: '开始日期',
          dataIndex: 'ksrq',
          sorter: true,
          width: 140,
          align: 'center',
        },
        {
          title: '结束日期',
          dataIndex: 'jsrq',
          sorter: true,
          width: 140,
          align: 'center',
        },

        // {
        //   title: '公司id',
        //   align: 'center',
        //   dataIndex: 'companyId'
        // },
        {
          title: '操作',
          dataIndex: 'action',
          fixed: 'right',
          scopedSlots: { customRender: 'action' },
          align: 'center',
          width: 150,
        },
      ],
      url: {
        list: '/pro/project/list',
        exportXlsUrl: '/pro/project/exportXls',
      },
    }
  },
  computed: {},
  created() {
    this.initDictConfig()
  },
  methods: {
    initDictConfig() {
      //初始化字典 - 性别
      initDictOptions('sys_user,post,username').then((res) => {
        if (res.success) {
          this.$set(this.userDictOptions, 'username', res.result)
        }
      })
    },
    openBoard(record) {
      //this.$refs.boardModal.show(record)
      //this.$router.push({ path: '/pro/board', query: { id: record.id } })
      this.$router.push({name:'pro-board',params: {id: record.id }})

    },
    showTimeLine(record) {
      this.$refs.timeLine.edit(record)
    },
    getPercentColor(value) {
      let p = Number(value)
      if (p >= 90 && p < 100) {
        return 'rgb(244, 240, 89)'
      } else if (p >= 100) {
        return 'red'
      } else {
        return 'rgb(16, 142, 233)'
      }
    },
    getPercentFormat(value) {
      if (value == 100) {
        return '完成'
      } else {
        return value + '%'
      }
    },
  },
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>